<?php
namespace Aws\BackupGateway\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Backup Gateway** service.
 */
class BackupGatewayException extends AwsException {}
